Enum wasi_common::ErrorKind [−][src]
pub enum ErrorKind {
Show variants
Noent,
TooBig,
Badf,
Exist,
Ilseq,
Inval,
Io,
Nametoolong,
Notdir,
Notsup,
Overflow,
Range,
Spipe,
NotCapable,
}Expand description
Internal error type for the wasi-common crate.
Contains variants of the WASI $errno type are added according to what is actually used internally by
the crate. Not all values are represented presently.
Variants
Errno::Noent: No such file or directory
Errno::TooBig: Argument list too long
Errno::Badf: Bad file descriptor
Errno::Exist: File exists
Errno::Ilseq: Illegal byte sequence
Errno::Inval: Invalid argument
Errno::Io: I/O error
Errno::Nametoolong: Filename too long
Errno::Notdir: Not a directory or a symbolic link to a directory.
Errno::Notsup: Not supported, or operation not supported on socket.
Errno::Overflow: Value too large to be stored in data type.
Errno::Range: Result too large
Errno::Spipe: Invalid seek
Errno::NotCapable: Not capable