pub struct I32Exit(pub i32);Expand description
An error returned from the proc_exit host syscall.
Embedders can test if an error returned from wasm is this error, in which case it may signal a non-fatal trap.
Tuple Fields
0: i32Trait Implementations
Sourceimpl Error for I32Exit
impl Error for I32Exit
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()